/*
 * Copyright 2021 Thingstream AG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <Arduino.h>

#include "battery.h"

/**
 * Measure and return battery parameters.
 * @param voltage A pointer for returning the voltage in mV
 * @param charge A pointer for returning the charge in %
 * @return false on error, otherwise true
 */
bool Battery_getState(uint16_t* voltage, uint16_t* charge)
{
    // Analog reference: 3300 mV
    // Voltage divider:  4.7M over 10M -> reading*147/100
    *voltage = analogRead(BAT_VOLT) * 147 * 3300 / 100 / 1023;
    // No fuel gauge, omit charge percentage
    *charge = 0;

    return true;
}
